/*
 * ch32sub.c
 *
 * the sub MCU is responsible for the following:
 * - user buttons (complete handling / filtering)
 * - rgb chip hw enable / disable
 * - IrDA rx/tx and IrDA transciever enable / disable
 * - accelerometer hardware interrupt
 *
 *  Created on: Oct 11, 2024
 *      Author: true
 */

#include "ch32sub.h"
#include "port_intr.h"

#include "../comm/i2c.h"



volatile uint8_t intr_flag = 0;



void ch32sub_isr()
{
    // we'll check what the MCU has to say when we're done processing
    intr_flag = 1;
}

void ch32sub_process()
{
    if (intr_flag) {
        intr_flag = 0;

        // get interrupt flags
    }
}

void ch32sub_init()
{
    // configure interrupt pin as pull-up
    // interrupt driven by CH32V003 is open drain active-lo
    GPIOB_ModeCfg(SUB_INTR_PIN, GPIO_ModeIN_PU);

    // register interrupt handler
    port_intr_cb_register(PORT_INTR_GPIOB, SUB_INTR_PIN_NR, ch32sub_isr);

    // configure interrupt to be rising edge
    GPIOB_ITModeCfg(SUB_INTR_PIN, GPIO_ITMode_RiseEdge);
}

// things to do
void ch32sub_rgb_hwen(uint8_t en)
{
    i2c_addr(SUB_I2C_ADDR, 1);
}
