/*
 * true's GAT Nametag
 * Rushed SUPERCON 8 EDITION
 * main MCU firmware
 * 2024 true
 *
 * the main MCU is responsible for the following:
 * - rendering OLED UI
 * - rendering LED programs
 * - storing fonts
 * - communicating with I2C devices, including:
 *   - oled display, accelerometer
 *   - eeprom, sub MCU, RGBLED controller
 * - implementing USB interface
 * - implementing BLE (maybe)
 *
 */

#include <hw/ch32sub.h>
#include "CH59x_common.h"

#include "port_intr.h"

#include "comm/i2c.h"

#include "hw/gat/gat_gpio.h"

#include "led/rgbled.h"




void ch59x_xtal_conf()
{
    HSECFG_Current(HSE_RCur_125);
    HSECFG_Capacitance(HSECap_14p);
}

int main()
{
    // configure clock
    ch59x_xtal_conf();
    SetSysClock(CLK_SOURCE_HSE_16MHz);

    // enable DC-DC converter; brings significant power saving
    PWR_DCDCCfg(ENABLE);

    // get i2c up and running
    i2c_init();

    // configure port-based interrupts (used for chsub interrupt, mainly)
    port_intr_init();

    // configure aux MCU initial settings, attention interrupt
    ch32sub_init();
    // and enable RGBLED controller hardware pin so the controller can wake up

    // configure RGBLED controller
    rgbled_init();

    // configure GAT aux GPIOs, get gat ID
    gat_gpio_init();
    // configure GAT i2c slave

    while(1) {
        // only care about aux MCU when all other processing is done
        ch32sub_process();
    }
}
